@@ -44,6 +44,9 @@
 MODULE_AUTHOR("Jouni Malinen");
 MODULE_DESCRIPTION("Host AP common routines");
 MODULE_LICENSE("GPL");
+#ifdef MODULE_VERSION
+MODULE_VERSION(PRISM2_VERSION);
+#endif
 
 #ifndef HOSTAP_CRYPT_MODULE
 /* Old hostap_crypt module is now part of hostap module. */
