@@ -45,6 +45,9 @@ MODULE_DESCRIPTION("Support for Intersil Prism2-based 802.11 wireless LAN "
 		   "cards (PC Card).");
 MODULE_SUPPORTED_DEVICE("Intersil Prism2-based WLAN cards (PC Card)");
 MODULE_LICENSE("GPL");
+#ifdef MODULE_VERSION
+MODULE_VERSION(PRISM2_VERSION);
+#endif
 
 
 static unsigned int irq_mask = 0xdeb8;
