@@ -461,6 +461,9 @@ static int prism2_download_genesis(local_info_t *local,
 	local->hw_downloading = 0;
 
 	PDEBUG(DEBUG_EXTRA2, "Trying to initialize card\n");
+	/* Make sure the INIT command does not generate a command completion
+	 * event by disabling interrupts. */
+	hfa384x_disable_interrupts(dev);
 	if (prism2_hw_init(dev, 1)) {
 		printk(KERN_DEBUG "%s: Initialization after genesis mode "
 		       "download failed\n", dev->name);
