@@ -37,7 +37,9 @@ MODULE_DESCRIPTION("Support for Intersil Prism2-based 802.11 wireless LAN "
 		   "cards (PLX).");
 MODULE_SUPPORTED_DEVICE("Intersil Prism2-based WLAN cards (PLX)");
 MODULE_LICENSE("GPL");
-
+#ifdef MODULE_VERSION
+MODULE_VERSION(PRISM2_VERSION);
+#endif
 
 static int ignore_cis = 0;
 MODULE_PARM(ignore_cis, "i");
