@@ -682,7 +682,8 @@ struct local_info {
 	char essid[MAX_SSID_LEN + 1];
 	char name[MAX_NAME_LEN + 1];
 	int name_set;
-	u16 channel_mask;
+	u16 channel_mask; /* mask of allowed channels */
+	u16 scan_channel_mask; /* mask of channels to be scanned */
 	struct comm_tallies_sums comm_tallies;
 	struct net_device_stats stats;
 	struct proc_dir_entry *proc;
@@ -825,16 +826,15 @@ struct local_info {
 
 	int host_roaming;
 	unsigned long last_join_time; /* time of last JoinRequest */
-	struct hfa384x_scan_result *last_scan_results;
+	struct hfa384x_hostscan_result *last_scan_results;
 	int last_scan_results_count;
-	struct hfa384x_hostscan_result *last_hostscan_results;
-	int last_hostscan_results_count;
 	enum { PRISM2_SCAN, PRISM2_HOSTSCAN } last_scan_type;
 	HOSTAP_QUEUE info_queue;
 	long pending_info; /* bit field of pending info_queue items */
 #define PRISM2_INFO_PENDING_LINKSTATUS 0
 #define PRISM2_INFO_PENDING_SCANRESULTS 1
 	int prev_link_status; /* previous received LinkStatus info */
+	int prev_linkstatus_connected;
 	u8 preferred_ap[6]; /* use this AP if possible */
 
 #ifdef PRISM2_CALLBACK
